#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-5rv1flizdJQDpPlEpR7U2C
key:                  haskell-language-server-2.3.0.0-5rv1flizdJQDpPlEpR7U2C
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  7e447faba8a35644dc4217b525613748
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-5rv1flizdJQDpPlEpR7U2C
depends:
    aeson-pretty-0.8.11-LNH6vlHSPAr76Nw3x4S9XI
    async-2.2.6-Cc2ylPSJ9T994nMR0Eaxyq base-4.18.2.1
    base16-bytestring-1.0.2.0-HKNPUjeO8LQ9RSeGAokMwf
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-EYRlHYNpqN36EzjsucJ4qd
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG directory-1.3.8.5
    extra-1.7.16-J2nH1si97LP2pkcRW1gnIU filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-20m8hSbV3dSB4eSmPaANSD
    githash-0.1.7.0-Gzf3QnhC8Vu2bLBSBbLufk
    hie-bios-0.12.0-DxNJ4M2pckRBngSovkQkwI
    hiedb-0.4.3.0-Ko0oMqKlCE3HsM5SK0VCr1
    hls-alternate-number-format-plugin-2.3.0.0-LD9V86PyWp4DlWUE4HYET
    hls-cabal-fmt-plugin-2.3.0.0-BXh3NisDzOACvMsC6FqFH6
    hls-cabal-plugin-2.3.0.0-Ep7ipYpIeQm66bcSdMIOMR
    hls-call-hierarchy-plugin-2.3.0.0-6Zg5ahqVGUA9YL85AxHPEs
    hls-change-type-signature-plugin-2.3.0.0-ACQPf5U5izZ6QIUbElsglo
    hls-class-plugin-2.3.0.0-GpA3qywBaU21mkVwjaXQlB
    hls-code-range-plugin-2.3.0.0-2jM7CLQK5t29kamNxtdXZ5
    hls-eval-plugin-2.3.0.0-GWuhhQUgV5eJzyOFPYaIB4
    hls-explicit-fixity-plugin-2.3.0.0-D61cyy6O2kiFOXNM61qRXK
    hls-explicit-imports-plugin-2.3.0.0-1TJG1NKz2kxHnQYEGJqPwV
    hls-explicit-record-fields-plugin-2.3.0.0-8bgSvWJQLLo5L7OHzchzVv
    hls-fourmolu-plugin-2.3.0.0-11l8hEMmwNYGiUg39OoJzR
    hls-gadt-plugin-2.3.0.0-KjhetSqOGag48sICO0CgXU
    hls-graph-2.3.0.0-DNh9jevvJmU9GPXOyACDPt
    hls-hlint-plugin-2.3.0.0-6qwsJk9l21hIEkaIiwttSP
    hls-module-name-plugin-2.3.0.0-IU973c44sdM9jKjX7f5KH5
    hls-ormolu-plugin-2.3.0.0-34iS2EyRJZY1aa7CiAjeGM
    hls-overloaded-record-dot-plugin-2.3.0.0-67KD3rod9UVHYlAzHDmP9H
    hls-plugin-api-2.3.0.0-E4eYBTbzbZDEQcf5rZNQAP
    hls-pragmas-plugin-2.3.0.0-K3hu4kfxxg0LsNunqLCLRk
    hls-qualify-imported-names-plugin-2.3.0.0-FZLuiQftr69JNdBaihpiUC
    hls-refactor-plugin-2.3.0.0-B1Nz6PcD3jELHrQo9h61hs
    hls-rename-plugin-2.3.0.0-GGOQZvnuzh0C33zJa4MsJB
    hls-retrie-plugin-2.3.0.0-bmHvqSHvb50cLk2ofBJ3
    hls-splice-plugin-2.3.0.0-C7wBSRSq7mxSsDZAtg1Ht
    hls-stylish-haskell-plugin-2.3.0.0-8xVvmXYYs0BNxoJTRHXO2
    lsp-2.2.0.0-KqYdVuca5eSIspYKEV6nVH
    optparse-applicative-0.18.1.0-2OPlFtvlr5yI8qFRB5F8bn
    optparse-simple-0.1.1.4-6yyKG2PP9WN5OyDvDQyo34
    prettyprinter-1.7.2-JipenGj1ZXCGzFGneLGC87 process-1.6.19.0
    safe-exceptions-0.1.7.4-EJ1HOjDpf87Jv7v1DsVVOt
    sqlite-simple-0.4.19.0-IuZ0Ce3SMCbLEYdJYMKdFR text-2.0.2
    unordered-containers-0.2.21-KyMpciGvYH9aykbB6p5Z

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

